#testing CV-related functions
library(PAFit)
prob_m <- "TRUE"
inc    <- "TRUE"
log    <-  c("TRUE")
mode_f_value <- c("Constant_PA", "Log_linear")[1]  
i      <- 1
net  <- GenerateNet(N = 50, m = 10,prob_m = prob_m, increase = inc, log = log,
                    mode = i, shape = 100, rate = 100,alpha = 0.5)



net_stats <- GetStatistics(net$graph,deg_threshold = 1, 
                           net_type = "directed",
                           Binning = TRUE, G = 10) 

result <- PAFit(net_stats,mode_f = "Log_linear",s = 100, debug = TRUE)

result_2 <- PAFit(net_stats, true_f = result$f, s = 100, debug = TRUE)

print(result)
